//------------------------------------------
//
//    Filter Actions
//
//------------------------------------------

/**
 * Display advanced options to be used in filters
 */

function advancedFilter(id, labelShow, labelHide) {
	
	var el = parent.Ext.get(id);
	if (el.dom.style.display == 'none') {
		el.fadeIn({ useDisplay: true });
		parent.Ext.get('advanced_filter_option').dom.innerHTML = labelHide;
	} else {
		el.fadeOut({ useDisplay: true });
		parent.Ext.get('advanced_filter_option').dom.innerHTML = labelShow;
	}
	
}

/**
 * Clean Host Grid filter form
 */

function cleanHostGridFilter() {
	
	parent.Ext.get('filter_host_name').dom.value = "";
	parent.Ext.get('filter_host_up').dom.checked = false;
	parent.Ext.get('filter_host_down').dom.checked = false;
	parent.Ext.get('filter_host_unreachable').dom.checked = false;
	parent.Ext.get('filter_host_soft').dom.checked = false;
	parent.Ext.get('filter_host_hard').dom.checked = false;
	parent.Ext.get('filter_host_ack').dom.checked = false;
	parent.Ext.get('filter_host_downtime').dom.checked = false;
	parent.Ext.get('filter_host_flapping').dom.checked = false;
	
	// Submit empty filter
	hostGridFilter();
	
	// Adjust icon
	parent.Ext.get('imgCleanFilter').addClass('opacity');
	
}

/**
 * Apply selected filters to Host Grid
 */

function hostGridFilter(event) {
	
	// Optional parameter
	if (event) {
		var key = event.keyCode || event.which;
		if (key != 13)
			return true;
	}
	
	// Adjust icon
	parent.Ext.get('imgCleanFilter').removeClass('opacity');
	
	// Create an empty filter rule
	var filterRules = new Array();
	
	// status UP
	var status_sql = new Array();
	var up = parent.Ext.get('filter_host_up').dom;
	if (up.checked) {
		filterRules.push("current_state;0");
	}
	
	// status DOWN
	var down = parent.Ext.get('filter_host_down').dom;
	if (down.checked) {
		filterRules.push("current_state;1");
	}
	
	// status UNRECHABLE
	var unreachable = parent.Ext.get('filter_host_unreachable').dom;
	if (unreachable.checked) {
		filterRules.push("current_state;2");
	}
	
	// SOT state
	var soft = parent.Ext.get('filter_host_soft').dom;
	if (soft.checked) {
		filterRules.push("state_type;2");
	}
	
	// HARD STATE
	var hard = parent.Ext.get('filter_host_hard').dom;
	if (hard.checked) {
		filterRules.push("state_type;1");
	}

	// ACK
	var ack = parent.Ext.get('filter_host_ack').dom;
	if (ack.checked) {
		filterRules.push("problem_has_been_acknowledged;1");
	}
	
	// DOWNTIME
	var downtime = parent.Ext.get('filter_host_downtime').dom;
	if (downtime.checked) {
		filterRules.push("scheduled_downtime_depth;1");
	}
	
	// FLAPPING
	var flapping = parent.Ext.get('filter_host_flapping').dom;
	if (flapping.checked) {
		filterRules.push("is_flapping;1");
	}
	
	// Host Name value
	var host_name_input = parent.Ext.get('filter_host_name').dom;
	var host_name = host_name_input.value;
	host_name_input.style.backgroundColor = "#FEDE77";
	if (host_name.length>0)
		filterRules.push("host_name;" + host_name);
	
	// Create the SQL
	var filterString = implode( "|", filterRules );
		
	// Keep filter in cookie
	deleteCookie('hostGridFilter', '/');
	if (filterString != 'undefined')
		setCookie('hostGridFilter', filterString, '365', '/', '', '' );
	
	var iframe = parent.Ext.get('mainFrame');
	
	// New URL
	var url = parent.window.frames['mFrame'].location.href;
	url = url.replace(/http[s]+:\/\/[^\/]*/, "");
	url = url.replace(/[&]*showpanel=.*/, "");
	
	if(url.match(/\?.+$/)) {
		url += '&';
	} else {
		url += '?';
	}

	if (filterString != 'undefined') {
		url += "useFilter=1";
		url += (filterString != 'undefined') ? "&filterString=" + filterString : "";
		iframe.dom.src = url;
	} else {
		url = url.replace(/\?useFilter.*$/, "");
		iframe.dom.src = url;
	}

}

/**
 * Clean Service Grid filter form
 */

function cleanServiceGridFilter() {
	
	parent.Ext.get('filter_name').dom.value = "";
	parent.Ext.get('filter_service_ok').dom.checked = false;
	parent.Ext.get('filter_service_warning').dom.checked = false;
	parent.Ext.get('filter_service_critical').dom.checked = false;
	parent.Ext.get('filter_service_unknown').dom.checked = false;
	parent.Ext.get('filter_service_soft').dom.checked = false;
	parent.Ext.get('filter_service_hard').dom.checked = false;
	parent.Ext.get('filter_service_ack').dom.checked = false;
	parent.Ext.get('filter_service_downtime').dom.checked = false;
	parent.Ext.get('filter_service_flapping').dom.checked = false;

	// Submit empty filter
	serviceGridFilter();
	
	// Adjust icon
	parent.Ext.get('imgCleanFilter').addClass('opacity');
	
}

/**
 * Apply selected filters to Service Grid
 */

function serviceGridFilter(event) {
	
	// Optional parameter
	if (event) {
		var key = event.keyCode || event.which;
		if (key != 13)
			return true;
	}
	
	// Adjust icon
	parent.Ext.get('imgCleanFilter').removeClass('opacity');
	
	// Create an empty filter rule
	var filterRules = new Array();
	
	// status OK
	var status_sql = new Array();
	var ok = parent.Ext.get('filter_service_ok').dom;
	if (ok.checked) {
		filterRules.push("current_state;0");
	}
	
	// status Warning
	var warn = parent.Ext.get('filter_service_warning').dom;
	if (warn.checked) {
		filterRules.push("current_state;1");
	}
	
	// status Critical
	var critical = parent.Ext.get('filter_service_critical').dom;
	if (critical.checked) {
		filterRules.push("current_state;2");
	}
	
	// status Unknown
	var unk = parent.Ext.get('filter_service_unknown').dom;
	if (unk.checked) {
		filterRules.push("current_state;3");
	}
	
	// SOT state
	var soft = parent.Ext.get('filter_service_soft').dom;
	if (soft.checked) {
		filterRules.push("state_type;0");
	}
	
	// HARD STATE
	var hard = parent.Ext.get('filter_service_hard').dom;
	if (hard.checked) {
		filterRules.push("state_type;1");
	}	

	// ACK
	var ack = parent.Ext.get('filter_service_ack').dom;
	if (ack.checked) {
		filterRules.push("problem_has_been_acknowledged;1");
	}
	
	// DOWNTIME
	var downtime = parent.Ext.get('filter_service_downtime').dom;
	if (downtime.checked) {
		filterRules.push("scheduled_downtime_depth;1");
	}
	
	// FLAPPING
	var flapping = parent.Ext.get('filter_service_flapping').dom;
	if (flapping.checked) {
		filterRules.push("is_flapping;1");
	}

	// Name value
	var name_input = parent.Ext.get('filter_name').dom;
	var name = name_input.value;
	name_input.style.backgroundColor = "#FEDE77";
	if (name.length>0)
		filterRules.push("name;" + name);
	
	
	// Create the SQL
	var filterString = implode( "|", filterRules );
		
	// Keep filter in cookie
	deleteCookie('serviceGridFilter', '/');
	if (filterString != 'undefined')
		setCookie('serviceGridFilter', filterString, '365', '/', '', '' );
	
	var iframe = parent.Ext.get('mainFrame');
	
	// New URL
	var url = parent.window.frames['mFrame'].location.href;
	url = url.replace(/http[s]+:\/\/[^\/]*/, "");
	url = url.replace(/[&]*showpanel=.*/, "");
	
	if(url.match(/\?.+$/)) {
		url += '&';
	} else {
		url += '?';
	}
	
	if (filterString != 'undefined') {
		url += "useFilter=1";
		url += (filterString != 'undefined') ? "&filterString=" + filterString : "";
		iframe.dom.src = url;
	} else {
		url = url.replace(/\?useFilter.*$/, "");
		iframe.dom.src = url;
	}
	
}


/**
 * Clean Hostgroup Grid filter form
 */
function cleanHostgroupGridFilter() {
	
	parent.Ext.get('filter_name').dom.value = "";
	parent.Ext.get('filter_host_up').dom.checked = false;
	parent.Ext.get('filter_host_down').dom.checked = false;
	parent.Ext.get('filter_host_unreachable').dom.checked = false;
	parent.Ext.get('filter_host_soft').dom.checked = false;
	parent.Ext.get('filter_host_hard').dom.checked = false;
	parent.Ext.get('filter_host_ack').dom.checked = false;
	parent.Ext.get('filter_host_downtime').dom.checked = false;
	parent.Ext.get('filter_host_flapping').dom.checked = false;
	
	// Submit empty filter
	hostgroupGridFilter();
	
	// Adjust icon
	parent.Ext.get('imgCleanFilter').addClass('opacity');
	
}

/**
 * Apply selected filters to Hostgroup Grid
 */

function hostgroupGridFilter(event) {
	
	// Optional parameter
	if (event) {
		var key = event.keyCode || event.which;
		if (key != 13)
			return true;
	}
	
	// Adjust icon
	parent.Ext.get('imgCleanFilter').removeClass('opacity');
	
	// Create an empty filter rule
	var filterRules = new Array();
	
	// status UP
	var status_sql = new Array();
	var up = parent.Ext.get('filter_host_up').dom;
	if (up.checked) {
		filterRules.push("current_state;0");
	}
	
	// status DOWN
	var down = parent.Ext.get('filter_host_down').dom;
	if (down.checked) {
		filterRules.push("current_state;1");
	}
	
	// status UNRECHABLE
	var unreachable = parent.Ext.get('filter_host_unreachable').dom;
	if (unreachable.checked) {
		filterRules.push("current_state;2");
	}
	
	// SOT state
	var soft = parent.Ext.get('filter_host_soft').dom;
	if (soft.checked) {
		filterRules.push("state_type;0");
	}
	
	// HARD STATE
	var hard = parent.Ext.get('filter_host_hard').dom;
	if (hard.checked) {
		filterRules.push("state_type;1");
	}

	// ACK
	var ack = parent.Ext.get('filter_host_ack').dom;
	if (ack.checked) {
		filterRules.push("problem_has_been_acknowledged;1");
	}
	
	// DOWNTIME
	var downtime = parent.Ext.get('filter_host_downtime').dom;
	if (downtime.checked) {
		filterRules.push("scheduled_downtime_depth;1");
	}
	
	// FLAPPING
	var flapping = parent.Ext.get('filter_host_flapping').dom;
	if (flapping.checked) {
		filterRules.push("is_flapping;1");
	}
	
	// Name value
	var name_input = parent.Ext.get('filter_name').dom;
	var name = name_input.value;
	name_input.style.backgroundColor = "#FEDE77";
	if (name.length>0)
		filterRules.push("name;" + name);
	
	// Create the SQL
	var filterString = implode( "|", filterRules );
		
	// Keep filter in cookie
	deleteCookie('hostgroupGridFilter', '/');
	if (filterString != 'undefined')
		setCookie('hostgroupGridFilter', filterString, '365', '/', '', '' );
	
	var iframe = parent.Ext.get('mainFrame');
	
	// New URL
	var url = parent.window.frames['mFrame'].location.href;
	url = url.replace(/http[s]+:\/\/[^\/]*/, "");
	url = url.replace(/[&]*showpanel=.*/, "");
	
	if(url.match(/\?.+$/)) {
		url += '&';
	} else {
		url += '?';
	}
	
	if (filterString != 'undefined') {
		url += "useFilter=1";
		url += (filterString != 'undefined') ? "&filterString=" + filterString : "";
		iframe.dom.src = url;
	} else {
		url = url.replace(/\?useFilter.*$/, "");
		iframe.dom.src = url;
	}
	
}

/**
 * Apply selected filters to Service Grid
 */

function servicegroupGridFilter(event) {
	
	// Optional parameter
	if (event) {
		var key = event.keyCode || event.which;
		if (key != 13)
			return true;
	}
	
	// Adjust icon
	parent.Ext.get('imgCleanFilter').removeClass('opacity');
	
	// Create an empty filter rule
	var filterRules = new Array();
	
	// status OK
	var status_sql = new Array();
	var ok = parent.Ext.get('filter_service_ok').dom;
	if (ok.checked) {
		filterRules.push("current_state;0");
	}
	
	// status Warning
	var warn = parent.Ext.get('filter_service_warning').dom;
	if (warn.checked) {
		filterRules.push("current_state;1");
	}
	
	// status Critical
	var critical = parent.Ext.get('filter_service_critical').dom;
	if (critical.checked) {
		filterRules.push("current_state;2");
	}
	
	// status Unknown
	var unk = parent.Ext.get('filter_service_unknown').dom;
	if (unk.checked) {
		filterRules.push("current_state;3");
	}
	
	// SOT state
	var soft = parent.Ext.get('filter_service_soft').dom;
	if (soft.checked) {
		filterRules.push("state_type;0");
	}
	
	// HARD STATE
	var hard = parent.Ext.get('filter_service_hard').dom;
	if (hard.checked) {
		filterRules.push("state_type;1");
	}	
	
	// ACK
	var ack = parent.Ext.get('filter_service_ack').dom;
	if (ack.checked) {
		filterRules.push("problem_has_been_acknowledged;1");
	}
	
	// DOWNTIME
	var downtime = parent.Ext.get('filter_service_downtime').dom;
	if (downtime.checked) {
		filterRules.push("scheduled_downtime_depth;1");
	}
	
	// FLAPPING
	var flapping = parent.Ext.get('filter_service_flapping').dom;
	if (flapping.checked) {
		filterRules.push("is_flapping;1");
	}
	
	// Name value
	var name_input = parent.Ext.get('filter_name').dom;
	var name = name_input.value;
	name_input.style.backgroundColor = "#FEDE77";
	if (name.length>0)
		filterRules.push("name;" + name);
	
	// Create the SQL
	var filterString = implode( "|", filterRules );
		
	// Keep filter in cookie
	deleteCookie('servicegroupGridFilter', '/');
	if (filterString != 'undefined')
		setCookie('servicegroupGridFilter', filterString, '365', '/', '', '' );
	
	var iframe = parent.Ext.get('mainFrame');
	
	// New URL
	var url = parent.window.frames['mFrame'].location.href;
	url = url.replace(/http[s]+:\/\/[^\/]*/, "");
	url = url.replace(/[&]*showpanel=.*/, "");
	
	if(url.match(/\?.+$/)) {
		url += '&';
	} else {
		url += '?';
	}
	
	if (filterString != 'undefined') {
		url += "useFilter=1";
		url += (filterString != 'undefined') ? "&filterString=" + filterString : "";
		iframe.dom.src = url;
	} else {
		url = url.replace(/\?useFilter.*$/, "");
		iframe.dom.src = url;
	}
	
}

/**
 * Clean filter form
 */
function cleanServicegroupGridFilter() {
	
	parent.Ext.get('filter_name').dom.value = "";
	parent.Ext.get('filter_service_ok').dom.checked = false;
	parent.Ext.get('filter_service_warning').dom.checked = false;
	parent.Ext.get('filter_service_critical').dom.checked = false;
	parent.Ext.get('filter_service_unknown').dom.checked = false;
	parent.Ext.get('filter_service_soft').dom.checked = false;
	parent.Ext.get('filter_service_hard').dom.checked = false;
	parent.Ext.get('filter_service_ack').dom.checked = false;
	parent.Ext.get('filter_service_downtime').dom.checked = false;
	parent.Ext.get('filter_service_flapping').dom.checked = false;
	
	// Submit empty filter
	servicegroupGridFilter();
	
	// Adjust icon
	parent.Ext.get('imgCleanFilter').addClass('opacity');
	
}

/**
 * Apply selected filters to notifications Grid
 */

function notificationsGridFilter(event) {
	
	// Optional parameter
	if (event) {
		var key = event.keyCode || event.which;
		if (key != 13)
			return true;
	}

	// Adjust icon
	parent.Ext.get('imgCleanFilter').removeClass('opacity');
	
	// String form
	var input = parent.Ext.get('nForm').dom.elements['notifications[string]'];
	input.style.backgroundColor = "#FEDE77";
	
	parent.Ext.get('nForm').dom.submit();
	
}

/**
 * Clean filter form
 */

function cleanNotificationGridFilter() {
	
	var aTmp = new Array();
	aTmp = parent.Ext.query('input');
	for( var i=0; i<aTmp.length; i++ ) { 
		var input = aTmp[i];
		if (input.type == 'checkbox')
			input.checked = false;
		else {
			input.style.backgroundColor = "#FFFFFF";
			input.value = "";
		}
	}

	// Adjust icon
	parent.Ext.get('imgCleanFilter').addClass('opacity');
	
	// Delete cookie
	deleteCookie('notificationsGridFilter', '/');
	
	// New URL
	var iframe = parent.Ext.get('mainFrame');
	var url = parent.window.frames['mFrame'].location.href;
	url = url.replace(/http[s]+:\/\/[^\/]*/, "");
	url = url.replace(/\?option.*$/,"");
	iframe.dom.src = url;
	
}

/**
 * Apply selected filters to events Grid
 */

function eventsGridFilter(event) {
	
	// Optional parameter
	if (event) {
		var key = event.keyCode || event.which;
		if (key != 13)
			return true;
	}

	// Adjust icon
	parent.Ext.get('imgCleanFilter').removeClass('opacity');
	
	// String form
	var input = parent.Ext.get('nForm').dom.elements['events[string]'];
	input.style.backgroundColor = "#FEDE77";
	
	parent.Ext.get('nForm').dom.submit();
	
}

/**
 * Clean filter form
 */

function cleanEventsGridFilter() {
	
	var aTmp = new Array();
	aTmp = parent.Ext.query('input');
	for( var i=0; i<aTmp.length; i++ ) { 
		var input = aTmp[i];
		if (input.type == 'checkbox')
			input.checked = false;
		else {
			input.style.backgroundColor = "#FFFFFF";
			input.value = "";
		}
	}

	// Adjust icon
	parent.Ext.get('imgCleanFilter').addClass('opacity');
	
	// Delete cookie
	deleteCookie('eventsGridFilter', '/');
	
	// New URL
	var iframe = parent.Ext.get('mainFrame');
	var url = parent.window.frames['mFrame'].location.href;
	url = url.replace(/http[s]+:\/\/[^\/]*/, "");
	url = url.replace(/\?option.*$/,"");
	iframe.dom.src = url;
	
}

/**
 * Apply selected filters to comments Grid
 */

function commentsGridFilter(event) {
	
	// Optional parameter
	if (event) {
		var key = event.keyCode || event.which;
		if (key != 13)
			return true;
	}

	// Adjust icon
	parent.Ext.get('imgCleanFilter').removeClass('opacity');
	
	// String form
	var input = parent.Ext.get('nForm').dom.elements['comments[string]'];
	input.style.backgroundColor = "#FEDE77";
	
	parent.Ext.get('nForm').dom.submit();
	
}

/**
 * Clean filter form
 */

function cleanCommentsGridFilter() {
	
	var aTmp = new Array();
	aTmp = parent.Ext.query('input');
	for( var i=0; i<aTmp.length; i++ ) { 
		var input = aTmp[i];
		if (input.type == 'checkbox')
			input.checked = false;
		else {
			input.style.backgroundColor = "#FFFFFF";
			input.value = "";
		}
	}

	// Adjust icon
	parent.Ext.get('imgCleanFilter').addClass('opacity');
	
	// Delete cookie
	deleteCookie('commentsGridFilter', '/');
	
	// New URL
	var iframe = parent.Ext.get('mainFrame');
	var url = parent.window.frames['mFrame'].location.href;
	url = url.replace(/http[s]+:\/\/[^\/]*/, "");
	url = url.replace(/\?option.*$/,"");
	iframe.dom.src = url;
	
}

/**
 * Apply selected filters to downtimes Grid
 */

function downtimesGridFilter(event) {
	
	// Optional parameter
	if (event) {
		var key = event.keyCode || event.which;
		if (key != 13)
			return true;
	}

	// Adjust icon
	parent.Ext.get('imgCleanFilter').removeClass('opacity');
	
	// String form
	var input = parent.Ext.get('nForm').dom.elements['downtimes[string]'];
	input.style.backgroundColor = "#FEDE77";
	
	parent.Ext.get('nForm').dom.submit();
	
}

/**
 * Clean filter form
 */

function cleanDowntimesGridFilter() {
	
	var aTmp = new Array();
	aTmp = parent.Ext.query('input');
	for( var i=0; i<aTmp.length; i++ ) { 
		var input = aTmp[i];
		if (input.type == 'checkbox')
			input.checked = false;
		else {
			input.style.backgroundColor = "#FFFFFF";
			input.value = "";
		}
	}

	// Adjust icon
	parent.Ext.get('imgCleanFilter').addClass('opacity');
	
	// Delete cookie
	deleteCookie('downtimesGridFilter', '/');
	
	// New URL
	var iframe = parent.Ext.get('mainFrame');
	var url = parent.window.frames['mFrame'].location.href;
	url = url.replace(/http[s]+:\/\/[^\/]*/, "");
	url = url.replace(/\?option.*$/,"");
	iframe.dom.src = url;
	
}